==> haskell-xss-sanitize-0.3.7.2-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xss-sanitize
version:              0.3.7.2
visibility:           public
id:                   xss-sanitize-0.3.7.2-D8z0iCoLf8lL5y3YcoFUas
key:                  xss-sanitize-0.3.7.2-D8z0iCoLf8lL5y3YcoFUas
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  70424e7eaac83a63fe1c6bcf29c6149e
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7.2-D8z0iCoLf8lL5y3YcoFUas
depends:
    attoparsec-0.14.4-H7aeDSX4mnyDRaYndD48j5 base-4.17.2.1
    containers-0.6.7 css-text-0.1.3.0-GwmOFwjZBO49uTXF2JCxgW
    network-uri-2.6.4.2-4dyZiFqUsAXDJ8mS3jtc8B
    tagsoup-0.14.8-3GR71DUnZfY7QLjBrHWIvS text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.7.2-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xss-sanitize
version:              0.3.7.2
visibility:           public
id:                   xss-sanitize-0.3.7.2-JgORxG2bttjGeJYPnbor6D
key:                  xss-sanitize-0.3.7.2-JgORxG2bttjGeJYPnbor6D
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  f35b58cc35ccc9d76e3bb64cf16eca2d
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xss-sanitize-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7.2-JgORxG2bttjGeJYPnbor6D
depends:
    attoparsec-0.14.4-IvgQrznNozFJRhxLBW8JF base-4.17.2.1
    containers-0.6.7 css-text-0.1.3.0-GRp7cuXZ4iGLV4KykTsRFY
    network-uri-2.6.4.2-yi3MP3fDM2AtnMkY6gtjY
    tagsoup-0.14.8-AQScOl7JAQZCQSVI62rKhC text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
